households.Member (Household Member) — amici1

# `households.Member` (Household Member)

Member(id, start_date, end_date, title, first_name, middle_name, last_name, gender, birth_date, role, person, household, dependency, primary)

Master tables : households.Members (Household Members)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Start date (start_date) : Since when this membership exists. This is usually empty.

- End date (end_date) : Until when this membership exists.

- Title (title) : Used to specify a professional position or academic qualification like « Dr. » or « PhD ».

- First name (first_name) : The first name, also known as given name.

- Middle name (middle_name) : A space-separated list of all middle names.

- Last name (last_name) : The last name, also known as family name.

- Gender (gender) : The sex of this person (male or female).

- Birth date (birth_date) : Uncomplete dates are allowed, e.g. « 00.00.1980 » means « some day in 1980 », « 00.07.1980 » means « in July 1980 » or « 23.07.0000 » means « on a 23th of July ».

- Role (role) : See `<lino.core.choicelists.ChoiceListField: role>`.

- Person (person) : See `<django.db.models.fields.related.ForeignKey: person>`.

- Household (household) : See `<django.db.models.fields.related.ForeignKey: household>`.

- Dependency (dependency) : See `<lino.core.choicelists.ChoiceListField: dependency>`.

- Primary (primary) : Whether this is the primary household of this person. Checking this field will automatically disable any other primary memberships.

- Name (name_column) : See `lino_xl.lib.households.models.Member.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.households.models.Member.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.households.models.Member.overview`.

- Age (age) : Virtual field displaying the age in years.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
start_date | Start date | Since when this membership exists. This is usually empty.
end_date | End date | Until when this membership exists.
title | Title | Used to specify a professional position or academic qualification like « Dr. » or « PhD ».
first_name | First name | The first name, also known as given name.
middle_name | Middle name | A space-separated list of all middle names.
last_name | Last name | The last name, also known as family name.
gender | Gender | The sex of this person (male or female).
birth_date | Birth date | Uncomplete dates are allowed, e.g. « 00.00.1980 » means « some day in 1980 », « 00.07.1980 » means « in July 1980 » or « 23.07.0000 » means « on a 23th of July ».
role | Role |
person | Person |
household | Household |
dependency | Dependency |
primary | Primary | Whether this is the primary household of this person. Checking this field will automatically disable any other primary memberships.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
age | Age | Virtual field displaying the age in years.